==> haskell-yesod-1.6.0-227-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.6.0
id: yesod-1.6.0-AsPzjlFpUqfAK7MnF85r9D
key: yesod-1.6.0-AsPzjlFpUqfAK7MnF85r9D
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
abi: ac7df7cec83d84e89cac1f20621e3603
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-1.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yesod-1.6.0
hs-libraries: HSyesod-1.6.0-AsPzjlFpUqfAK7MnF85r9D
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 directory-1.3.3.0
    fast-logger-2.4.13-7XFzh3aQWnlKlUKecZBtaB
    monad-logger-0.3.30-4p5DJfT2GaS3GG1i0T5LBK
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
    shakespeare-2.0.20-8RmIEUFqLBODHsEAdHA6sa
    streaming-commons-0.2.1.0-LU7KRMKFZnk5zfd2Cwdxoq
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-2.7.2.2 unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
    wai-extra-3.0.25-3NCy54OLMkw8Cxl4RTvM7W
    wai-logger-2.3.4-4ejuhiJHJxRK3doVXURMNX
    warp-3.2.26-4Z54Y616a5OBqJ9CXkVTYc
    yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
    yesod-core-1.6.12-Jv8nnBFoHox7bqzf1TD1Jw
    yesod-form-1.6.4-AjfOxMd2IH050XifyN4EI6
    yesod-persistent-1.6.0.1-Erfv5nyiHal1Zbgi8ByHxq
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.6.0-228-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.6.0
id: yesod-1.6.0-JrSYCggt8Q2L13qKaI3y
key: yesod-1.6.0-JrSYCggt8Q2L13qKaI3y
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
abi: c5f6e3090612dad6c6dce3b6315bac97
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-1.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yesod-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yesod-1.6.0
hs-libraries: HSyesod-1.6.0-JrSYCggt8Q2L13qKaI3y
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 directory-1.3.3.0
    fast-logger-2.4.13-7XFzh3aQWnlKlUKecZBtaB
    monad-logger-0.3.30-4p5DJfT2GaS3GG1i0T5LBK
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
    shakespeare-2.0.20-8RmIEUFqLBODHsEAdHA6sa
    streaming-commons-0.2.1.0-LU7KRMKFZnk5zfd2Cwdxoq
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-2.7.2.2 unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
    wai-extra-3.0.25-3NCy54OLMkw8Cxl4RTvM7W
    wai-logger-2.3.4-4ejuhiJHJxRK3doVXURMNX
    warp-3.2.26-4Z54Y616a5OBqJ9CXkVTYc
    yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
    yesod-core-1.6.13-AxB51UfQWMo3YfYyUlXkSR
    yesod-form-1.6.4-85AjirtIjmo8BfiTPFLnNT
    yesod-persistent-1.6.0.1-8RTQ0QfjRxbJe3vML1hKKH
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
